@import "colors-kmuhelper.css";

.app-kmuhelper * {
    --primary: var(--kmuhelper-default);
    --secondary: var(--kmuhelper-darkest);
    --link-fg: var(--kmuhelper-dark);
    --link-selected-fg: var(--kmuhelper-light);
}
