{% extends "admin/kmuhelper/app_index.html" %}

{% block title %}KMUHelper App{% endblock %}

{% block content_title %}
    <h1>Willkommen in der KMUHelper App!</h1>
{% endblock %}

{% block branding %}
    <h1 id="site-name"><a target="_top" href="{% url 'kmuhelper:home' %}">KMUHelper</a> | <a target="_top" href="{% url 'kmuhelper:app-desktop' %}">App</a></h1>
{% endblock %}

{% block pageinfo %}
    <p id="pageinfo">
        In diesem Bereich hast du Zugriff auf bereits bekannt Seiten des <a href="{% url 'admin:app_list' app_label='kmuhelper' %}" target="_top">Adminbereichs</a>, 
        jedoch auf eine etwas andere Art.
        Sie ist dazu gedacht, für bestimmte Arbeitsschritte eine einfache Massenverarbeitung zu ermöglichen.
    </p>
    <br>
{% endblock %}

{% block pagelist %}    
    <div id="pagelist-container">
        <h3>Erklärungen der Seiten</h3>
        <ul style="padding-left: 16px;" id="pagelist">
            <li>
                <i class="fas fa-clipboard-list"></i><span>ToDo-Liste (Unerledigte Notizen)</span>
                <p>Erstelle dir eine To-Do Liste (Erledigte Einträge sind weiterhin im Adminbereich unter "Notizen" ersichtlich.)</p>
            </li>
            <li>
                <i class="fas fa-shipping-fast"></i><span>Versand (Unversendete Bestellungen)</span>
                <p>Füge Trackingnummern zu Bestellungen hinzu und markiere sie als versendet.</p>
            </li>
            <li>
                <i class="fas fa-hand-holding-usd"></i><span>Zahlungseingang (Unbezahlte Bestellungen)</span>
                <p>Vergleiche deinen Kontoauszug mit den offenen Bestellungen und markiere bezahlte Bestellungen als bezahlt.</p>
                <p>
                    <strong>
                        NEU:
                        <a target="_blank" href="{% url 'admin:kmuhelper_paymentimport_upload' %}">
                            Zahlungsimport von camt.053d XML-Dateien
                        </a>
                    </strong>
                </p>
            </li>
            <li>
                <i class="fas fa-warehouse"></i><span>Lagerbestand (Produkte)</span>
                <p>Sieh dir den Lagerbestand an und nimm manuelle Änderungen daran vor.</p>
            </li>
            <li>
                <i class="fas fa-truck-loading"></i><span>Wareneingang (Lieferungen)</span>
                <p>Erfasse Lieferungen und lagere sie ein. (Eingelagerte Lieferungen sind weiterhin im Adminbereich unter "Lieferungen" ersichtlich.)</p>
            </li>
        </ul>
    </div>
{% endblock %}
