# Generated by Django 3.2 on 2021-04-20 21:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0071_paymentimport_paymentimportentry'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='paymentimportentry',
            options={'default_permissions': (), 'verbose_name': 'Zahlungsimport-Eintrag', 'verbose_name_plural': 'Zahlungsimport-Einträge'},
        ),
        migrations.RenameField(
            model_name='paymentimport',
            old_name='is_parsed',
            new_name='is_processed',
        ),
    ]
