# Generated by Django 4.1.5 on 2023-01-29 19:26

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("kmuhelper", "0085_alter_bestellungskosten_name_alter_kosten_name_and_more"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="Produktkategorie",
            new_name="ProduktProduktkategorieVerbindung",
        ),
        migrations.RenameModel(
            old_name="Kategorie",
            new_name="Produktkategorie",
        ),
        migrations.AlterModelOptions(
            name="produktkategorie",
            options={
                "verbose_name": "Produktkategorie",
                "verbose_name_plural": "Produktkategorien",
            },
        ),
        migrations.AlterModelOptions(
            name="produktproduktkategorieverbindung",
            options={
                "verbose_name": "Produkt-Kategorie-Verknüpfung",
                "verbose_name_plural": "Produkt-Kategorie-Verknüpfungen",
            },
        ),
    ]
