{% extends 'admin/kmuhelper/_special/emails/change_list.html' %}

{% block object-tools-items %}
    {% if perms.kmuhelper.add_email %}
        {% if 'emailtemplate-vars' in request.session %}
            <li>
                <a href="{% url 'admin:kmuhelper_emailtemplate_resetvars' %}">Gespeicherte Variablen löschen</a>
            </li>
        {% endif %}
    {% endif %}
    {{ block.super }}
{% endblock %}