# Generated by Django 4.1.5 on 2023-01-29 18:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("kmuhelper", "0083_alter_zahlungsempfaenger_webseite"),
    ]

    operations = [
        migrations.AlterField(
            model_name="produkt",
            name="mengenbezeichnung",
            field=models.CharField(
                blank=True,
                default="Stück",
                max_length=100,
                verbose_name="Mengenbezeichnung",
            ),
        ),
    ]
