# Generated by Django 3.2 on 2021-04-17 19:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0069_auto_20210417_2007'),
    ]

    operations = [
        migrations.AddField(
            model_name='einstellung',
            name='json',
            field=models.JSONField(blank=True, default=dict, null=True, verbose_name='Inhalt (JSON)'),
        ),
        migrations.AddField(
            model_name='geheime_einstellung',
            name='json',
            field=models.JSONField(blank=True, default=dict, null=True, verbose_name='Inhalt (JSON)'),
        ),
        migrations.AlterField(
            model_name='einstellung',
            name='typ',
            field=models.CharField(choices=[('char', 'Text'), ('text', 'Mehrzeiliger Text'), ('bool', 'Wahrheitswert'), ('int', 'Zahl'), ('float', 'Fliesskommazahl'), ('url', 'Url'), ('email', 'E-Mail'), ('json', 'JSON Daten')], default='char', max_length=5, verbose_name='Typ'),
        ),
        migrations.AlterField(
            model_name='geheime_einstellung',
            name='typ',
            field=models.CharField(choices=[('char', 'Text'), ('text', 'Mehrzeiliger Text'), ('bool', 'Wahrheitswert'), ('int', 'Zahl'), ('float', 'Fliesskommazahl'), ('url', 'Url'), ('email', 'E-Mail'), ('json', 'JSON Daten')], default='char', max_length=5, verbose_name='Typ'),
        ),
    ]
