{% extends "admin/index.html" %}
{% load static %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static "admin/kmuhelper/css/index-kmuhelper.css" %}">
    <link rel="stylesheet" href="https://use.fontawesome.com/releases/v6.0.0/css/all.css">
{% endblock %}

{% block content %}

    {% if not app_label %}
        <style>
            #kmuhelperbutton {
                padding: 0.5em 2em 1em;
                border-radius: 5px;
                display: block;
                color: white;
                background-color: var(--kmuhelper-dark);
                transition-duration: 0.5s;
                text-decoration: none !important;
            }

            #kmuhelperbutton:hover {
                background-color: var(--kmuhelper-darkest);
            }

            #kmuhelperbutton h2 {
                display: inline-block;
                margin-left: 1em;
            }
        </style>
        <div style="margin-bottom: 32px;">
            <a href="{% url 'kmuhelper:home' %}" id="kmuhelperbutton">
                <i class="fa-fw fas fa-box-open"></i>
                <h2>KMUHelper öffnen</h2>
            </a>
        </div>
    {% endif %}

    {{ block.super }}
{% endblock %}