# Generated by Django 3.2 on 2021-04-13 17:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0059_alter_email_html_context'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='email',
            name='typ',
        ),
    ]
