# Generated by Django 3.2 on 2021-04-22 11:23

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0072_auto_20210420_2335'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentimportentry',
            name='additionalref',
            field=models.CharField(default='', max_length=250, verbose_name='Zusätzliche Referenz'),
        ),
        migrations.AddField(
            model_name='paymentimportentry',
            name='valuedate',
            field=models.DateField(null=True, verbose_name='Valuta'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='kunde',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='bestellungen', to='kmuhelper.kunde'),
        ),
        migrations.AlterField(
            model_name='paymentimportentry',
            name='iban',
            field=models.CharField(default='', max_length=22, verbose_name='IBAN'),
        ),
        migrations.AlterField(
            model_name='paymentimportentry',
            name='name',
            field=models.CharField(default='', max_length=250, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='paymentimportentry',
            name='ref',
            field=models.CharField(default='', max_length=50, verbose_name='Referenznummer'),
        ),
    ]
