# Generated by Django 3.2.10 on 2022-03-05 22:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0078_auto_20211122_1926'),
    ]

    operations = [
        migrations.RenameField(
            model_name='einstellung',
            old_name='boo',
            new_name='content_bool',
        ),
        migrations.RenameField(
            model_name='einstellung',
            old_name='char',
            new_name='content_char',
        ),
        migrations.RenameField(
            model_name='einstellung',
            old_name='email',
            new_name='content_email',
        ),
        migrations.RenameField(
            model_name='einstellung',
            old_name='floa',
            new_name='content_float',
        ),
        migrations.RenameField(
            model_name='einstellung',
            old_name='inte',
            new_name='content_int',
        ),
        migrations.RenameField(
            model_name='einstellung',
            old_name='json',
            new_name='content_json',
        ),
        migrations.RenameField(
            model_name='einstellung',
            old_name='text',
            new_name='content_text',
        ),
        migrations.RenameField(
            model_name='einstellung',
            old_name='url',
            new_name='content_url',
        ),
        migrations.RenameField(
            model_name='geheime_einstellung',
            old_name='boo',
            new_name='content_bool',
        ),
        migrations.RenameField(
            model_name='geheime_einstellung',
            old_name='char',
            new_name='content_char',
        ),
        migrations.RenameField(
            model_name='geheime_einstellung',
            old_name='email',
            new_name='content_email',
        ),
        migrations.RenameField(
            model_name='geheime_einstellung',
            old_name='floa',
            new_name='content_float',
        ),
        migrations.RenameField(
            model_name='geheime_einstellung',
            old_name='inte',
            new_name='content_int',
        ),
        migrations.RenameField(
            model_name='geheime_einstellung',
            old_name='json',
            new_name='content_json',
        ),
        migrations.RenameField(
            model_name='geheime_einstellung',
            old_name='text',
            new_name='content_text',
        ),
        migrations.RenameField(
            model_name='geheime_einstellung',
            old_name='url',
            new_name='content_url',
        ),
    ]
