# Generated by Django 3.0.4 on 2020-07-16 15:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0023_auto_20200716_1553'),
    ]

    operations = [
        migrations.CreateModel(
            name='ToDoZahlungseingang',
            fields=[
            ],
            options={
                'verbose_name': 'ToDo Zahlungseingang',
                'verbose_name_plural': 'ToDo Zahlungseingang',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('kmuhelper.bestellung',),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='rechnungsadresse_adresszeile1',
            field=models.CharField(blank=True, default='', help_text='Strasse und Hausnummer oder "Postfach" ohne Nummer - Wird bei QR-Rechnung als Strasse und Hausnummer bzw. Postfach verwendet!', max_length=50, verbose_name='Adresszeile 1'),
        ),
    ]
