# Generated by Django 3.1.2 on 2020-10-10 14:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0040_auto_20201009_2329'),
    ]

    operations = [
        migrations.AddField(
            model_name='einstellung',
            name='email',
            field=models.EmailField(blank=True, default='', max_length=254, verbose_name='Inhalt (E-Mail)'),
        ),
        migrations.AddField(
            model_name='geheime_einstellung',
            name='email',
            field=models.EmailField(blank=True, default='', max_length=254, verbose_name='Inhalt (E-Mail)'),
        ),
        migrations.AlterField(
            model_name='einstellung',
            name='char',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Inhalt (Text)'),
        ),
        migrations.AlterField(
            model_name='einstellung',
            name='floa',
            field=models.FloatField(blank=True, default=0.0, verbose_name='Inhalt (Fliesskommazahl)'),
        ),
        migrations.AlterField(
            model_name='einstellung',
            name='inte',
            field=models.IntegerField(blank=True, default=0, verbose_name='Inhalt (Zahl)'),
        ),
        migrations.AlterField(
            model_name='einstellung',
            name='text',
            field=models.TextField(blank=True, default='', verbose_name='Inhalt (Mehrzeiliger Text)'),
        ),
        migrations.AlterField(
            model_name='einstellung',
            name='typ',
            field=models.CharField(choices=[('char', 'Text'), ('text', 'Mehrzeiliger Text'), ('int', 'Zahl'), ('float', 'Fliesskommazahl'), ('url', 'Url'), ('email', 'E-Mail')], default='char', max_length=5, verbose_name='Typ'),
        ),
        migrations.AlterField(
            model_name='einstellung',
            name='url',
            field=models.URLField(blank=True, default='', verbose_name='Inhalt (Url)'),
        ),
        migrations.AlterField(
            model_name='geheime_einstellung',
            name='char',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Inhalt (Text)'),
        ),
        migrations.AlterField(
            model_name='geheime_einstellung',
            name='floa',
            field=models.FloatField(blank=True, default=0.0, verbose_name='Inhalt (Fliesskommazahl)'),
        ),
        migrations.AlterField(
            model_name='geheime_einstellung',
            name='inte',
            field=models.IntegerField(blank=True, default=0, verbose_name='Inhalt (Zahl)'),
        ),
        migrations.AlterField(
            model_name='geheime_einstellung',
            name='text',
            field=models.TextField(blank=True, default='', verbose_name='Inhalt (Mehrzeiliger Text)'),
        ),
        migrations.AlterField(
            model_name='geheime_einstellung',
            name='typ',
            field=models.CharField(choices=[('char', 'Text'), ('text', 'Mehrzeiliger Text'), ('int', 'Zahl'), ('float', 'Fliesskommazahl'), ('url', 'Url'), ('email', 'E-Mail')], default='char', max_length=5, verbose_name='Typ'),
        ),
        migrations.AlterField(
            model_name='geheime_einstellung',
            name='url',
            field=models.URLField(blank=True, default='', verbose_name='Inhalt (Url)'),
        ),
    ]
